==> App-Dapper-0.06.tar.gz: App-Dapper-0.06/README.md <==
# Dapper README

Dapper is a publishing platform for static websites.

Distributed as a Perl module, App::Dapper comes with an
application called "dapper" which makes it easy to use the App::Dapper perl
module from the command line to create static websites.

## Installation

Install from CPAN:

    $ cpan App::Dapper

Install from source:

	$ perl Makefile.PL
	$ make
	$ make test
	$ make install

## Support and Documentation

After installing, you can find documentation for this module with the
perldoc command.

    perldoc App::Dapper

You can also look for information at:

* [Source on Github](https://github.com/markdbenson/dapper)

* [Submit an issue on Github](https://github.com/markdbenson/dapper/issues)

* [Module on CPAN](http://search.cpan.org/dist/App-Dapper/)

* [AnnoCPAN, Annotated CPAN documentation](http://annocpan.org/dist/App-Dapper)

* [CPAN Ratings](http://cpanratings.perl.org/d/App-Dapper)

## License and Copyright

The MIT License (MIT)

Copyright (c) 2002-2014 Mark Benson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> App-Dapper-0.11.tar.gz: App-Dapper-0.11/README.md <==
# Dapper README

Dapper is a publishing tool for static websites.

Distributed as a Perl module, App::Dapper comes with an application called
"dapper" which you can use from the command line and makes it easy to use
the App::Dapper perl module to create static websites.

## Installation

Install from CPAN:

    $ cpanm App::Dapper

If you don't have cpanm, install it like this:

    $ cpan App::cpanminus

Alternatively, install from source. A list of past releases can be found on
[backpan](http://backpan.perl.org/authors/id/M/MD/MDB/):

	$ perl Makefile.PL
	$ make
	$ make test
	$ make install

## Support and Documentation

After installing, you can find documentation for this module with the
perldoc command.

    perldoc App::Dapper

You can also look for information at:

* [Find the module on CPAN](http://search.cpan.org/dist/App-Dapper/)

* [Find source code on Github](https://github.com/markdbenson/dapper)

* [Submit an issue on Github](https://github.com/markdbenson/dapper/issues)

* [Find historical releases on BackPAN](http://backpan.perl.org/authors/id/M/MD/MDB/)

## License and Copyright

The MIT License (MIT)

Copyright (c) 2002-2014 Mark Benson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
